@@ -17,7 +17,7 @@ from boto3.session import Session
 
 
 __author__ = 'Amazon Web Services'
-__version__ = '1.4.4'
+__version__ = '1.4.5'
 
 
 # The default Boto3 session; autoloaded when needed.
@@ -65,7 +65,7 @@ def _get_default_session():
     """
     Get the default session, creating one if needed.
 
-    :rtype: :py:class:`~boto3.session.Sesssion`
+    :rtype: :py:class:`~boto3.session.Session`
     :return: The default session
     """
     if DEFAULT_SESSION is None:
